@@ -570,15 +570,17 @@ rose_grid <- function(angles, radii, add = TRUE) {
 #' x <- rvm(100, mean = 90, k = 5)
 #' rose(x, axial = FALSE, border = TRUE, grid = TRUE)
 #'
-#' data("san_andreas") #'
+#' data("san_andreas")
 #' rose(san_andreas$azi, main = "equal area")
 #' rose(san_andreas$azi, equal_area = FALSE, main = "equal angle")
 #'
 #' # weighted frequencies:
 #' rose(san_andreas$azi, weights = 1 / san_andreas$unc, main = "weighted")
 #'
-#' # add dots
+#' # add dots:
 #' rose(san_andreas$azi, dots = TRUE, main = "dot plot", jitter = .2)
+#'
+#' # stack dots:
 #' rose(san_andreas$azi,
 #'   dots = TRUE, stack = TRUE, dot_cex = 0.5, dot_pch = 21,
 #'   main = "stacked dot plot"
@@ -814,9 +816,15 @@ rose_stats <- function(x, weights = NULL, axial = TRUE, avg = c("mean", "median"
 #'
 #' @examples
 #' x <- rvm(100, mean = 90, k = 5)
+#'
+#' # plot poinit without jitter
 #' plot_points(x, add = FALSE)
-#' plot_points(x, jitter_factor = .2, add = FALSE) # jittered plot
-#' plot_points(x, stack = TRUE, binwidth = 3, add = FALSE) # stacked plot
+#'
+#' # with some jitter
+#' plot_points(x, jitter_factor = .2, add = FALSE)
+#'
+#' # stacked dots:
+#' plot_points(x, stack = TRUE, binwidth = 3, add = FALSE)
 plot_points <- function(x, axial = TRUE, stack = FALSE, binwidth = 1, cex = 1, sep = 0.025, jitter_factor = 0, ..., scale = 1.1, add = TRUE,
                         main = NULL, labels = TRUE,
                         at = seq(0, 360 - 45, 45), cborder = TRUE) {
@@ -870,10 +878,11 @@ plot_points <- function(x, axial = TRUE, stack = FALSE, binwidth = 1, cex = 1, s
 
 # Plot density lines on rose ---------------------------------------------------
 
-calc_circular_density <- function(x, z, kappa) {
+calc_circular_density <- function(x, z, kappa, axial) {
   nx <- length(x)
   # if (kernel == "vonmises") {
-  y <- sapply(z, dvm, mean = x, kappa = kappa)
+  y <- sapply(z, FUN = dvm, mean = x, kappa = kappa, axial = axial, log = FALSE)
+
   # }
   # else if (kernel == "wrappednormal") {
   #   rho <- exp(-bw^2/2)
@@ -888,8 +897,11 @@ calc_circular_density <- function(x, z, kappa) {
 
 
 circular_density <- function(x, z = NULL, kappa, na.rm = TRUE, from = 0, to = 360, n = 512, axial = TRUE) {
-  f <- as.numeric(axial) + 1
-  x <- x * f
+  # f <- as.numeric(axial) + 1
+  # x <- x * f
+
+  if (is.null(kappa)) kappa <- est.kappa(x, axial = axial, na.rm = na.rm)
+
 
   if (is.null(z)) {
     z <- seq(from = from, to = to, length = n)
@@ -912,7 +924,7 @@ circular_density <- function(x, z = NULL, kappa, na.rm = TRUE, from = 0, to = 36
     }
   }
 
-  calc_circular_density(x, z, kappa)
+  calc_circular_density(x, z, kappa = kappa, axial = axial)
 }
 
 circular_lines <- function(x, y, join = FALSE, nosort = FALSE, offset = 1.1, shrink = 1, axial = TRUE, ...) {
@@ -923,7 +935,6 @@ circular_lines <- function(x, y, join = FALSE, nosort = FALSE, offset = 1.1, shr
     y <- rep(y, 2)
   }
 
-
   n <- length(x)
   if (!nosort) {
     xorder <- order(x)
@@ -958,7 +969,7 @@ circular_lines <- function(x, y, join = FALSE, nosort = FALSE, offset = 1.1, shr
 #'
 #' @param x Data to be plotted. A numeric vector containing angles (in degrees).
 #' @param kappa Concentration parameter for the von Mises distribution.
-#' Small kappa gives smooth density lines.
+#' Small kappa gives smooth density lines. Will be estimated using [est.kappa()] if not provided.
 #' @param axial Logical. Whether data are uniaxial (`axial=FALSE`)
 #' or biaxial (`TRUE`, the default).
 #' @param n the number of equally spaced points at which the density is to be estimated.
@@ -975,16 +986,21 @@ circular_lines <- function(x, y, join = FALSE, nosort = FALSE, offset = 1.1, shr
 #' @export
 #'
 #' @examples
+#' # Plot the rose histogram first:
 #' rose(san_andreas$azi, dots = TRUE, stack = TRUE, dot_cex = 0.5, dot_pch = 21)
+#'
+#' # Add density curve outside of main plot:
 #' plot_density(san_andreas$azi,
 #'   kappa = 100, col = "#51127CFF", shrink = 1.5,
 #'   norm.density = FALSE
 #' )
+#'
+#' # Plot density inside plot only:
 #' plot_density(san_andreas$azi,
 #'   kappa = 100, col = "#51127CFF", add = FALSE,
 #'   scale = .5, shrink = 2, norm.density = TRUE, grid = TRUE
 #' )
-plot_density <- function(x, kappa, axial = TRUE, n = 512, norm.density = FALSE, ...,
+plot_density <- function(x, kappa = NULL, axial = TRUE, n = 512, norm.density = FALSE, ...,
                          scale = 1.1, shrink = 1,
                          add = TRUE, main = NULL, labels = TRUE,
                          at = seq(0, 360 - 45, 45), cborder = TRUE, grid = FALSE) {
@@ -999,7 +1015,9 @@ plot_density <- function(x, kappa, axial = TRUE, n = 512, norm.density = FALSE,
     rose_grid(seq(0, 135, 45), seq(.2, 1, .2))
   }
 
-  f <- as.numeric(axial) + 1
+
+  # f <- as.numeric(axial) + 1
+  f <- 1
   d <- circular_density(x, kappa = kappa, n = n, axial = axial)
   if (norm.density) {
     d <- d / max(d)
@@ -1067,7 +1085,10 @@ plot_density <- function(x, kappa, axial = TRUE, n = 512, norm.density = FALSE,
 #' data("san_andreas")
 #' res <- PoR_shmax(san_andreas, na_pa, "right")
 #' d <- distance_from_pb(san_andreas, na_pa, plate_boundary, tangential = TRUE)
-#' quick_plot(res$azi.PoR, d, res$prd, san_andreas$unc, san_andreas$regime)
+#' quick_plot(res$azi.PoR,
+#'   distance = d, prd = res$prd, unc = san_andreas$unc,
+#'   regime = san_andreas$regime
+#' )
 quick_plot <- function(
     azi,
     distance,
@@ -1278,7 +1299,7 @@ PoR_map <- function(x, PoR, pb = NULL, type = c("none", "in", "out", "right", "l
   val <- val2 <- character()
   type <- match.arg(type)
   x_por_df <- PoR_shmax(x, PoR, type = type)
-  if (type == "none") {
+  if (type == "none" | is.null(type)) {
     x_por_df <- data.frame(azi.PoR = x_por_df)
   }
 
