@@ -10,7 +10,7 @@ data("plates")
 na_pa_boundary <- subset(plates, plates$pair == "na-pa")
 # Load the current plate motion (cpm) models:
 data("cpm_models")
-morvel <- subset(cpm_models, model == "NNR-MORVEL56") # select MORVEL model
+morvel <- cpm_models[["NNR-MORVEL56"]] # select MORVEL model
 # Relative plate motion between Pacific and North American plates:
 na_pa <- equivalent_rotation(morvel, fixed = "na", rot = "pa")
 # Transform stress data set and test against predicted left-lateral tangential plate boundary (left):
@@ -70,6 +70,11 @@ p2 <- c(35, 135) # Osaka
 p3 <- c(35, NA) # add NA values
 get_azimuth(p3[1], p3[2], p2[1], p2[2])
 
+ep.geo <- c(20, 33)
+q.geo <- c(10, 45)
+q.por <- geographical_to_PoR_quat(q.geo, ep.geo)
+q.por
+PoR_to_geographical_quat(q.por, ep.geo)
 
 
 euler <- subset(nuvel1, nuvel1$plate.rot == "na")
@@ -178,7 +183,7 @@ test_that("Azimuth back conversion", {
   expect_equal(PoR2Geo_azimuth(iceland, eu_na), iceland$azi %% 180)
   expect_equal(PoR2Geo_azimuth(tibet, eu_in), tibet$azi %% 180)
 
-  san_andreas_por <- geographical_to_PoR_sf(san_andreas, na_pa)
+  san_andreas_por <- geographical_to_PoR(san_andreas, na_pa)
   por_crds <- sf::st_coordinates(san_andreas_por) |> as.data.frame()
   san_andreas_por$lat.PoR <- por_crds$Y
   san_andreas_por$lon.PoR <- por_crds$X
@@ -186,8 +191,8 @@ test_that("Azimuth back conversion", {
   expect_equal(round(PoR2Geo_azimuth(san_andreas_por, na_pa), 12) %% 180, san_andreas$azi %% 180)
 })
 
-test_that("Cooridnate conversion sf", {
-  san_andreas_por <- geographical_to_PoR_sf(san_andreas, na_pa) |>
+test_that("Coordinate conversion sf", {
+  san_andreas_por <- geographical_to_PoR(san_andreas, na_pa) |>
     PoR_to_geographical_sf(na_pa)
   por_crds <- sf::st_coordinates(san_andreas_por)
   geo_crds <- sf::st_coordinates(san_andreas)
@@ -195,7 +200,7 @@ test_that("Cooridnate conversion sf", {
   expect_equal(por_crds, geo_crds)
 })
 
-test_that("Cooridnate conversion df", {
+test_that("Coordinate conversion df", {
   geo_crds <- sf::st_coordinates(san_andreas)
 
   san_andreas_por2 <- geographical_to_PoR(san_andreas, na_pa) |>
